@@ -9,6 +9,7 @@ import pytest
 from logitech_receiver import common
 from logitech_receiver import hidpp10
 from logitech_receiver import hidpp10_constants
+from logitech_receiver.hidpp10_constants import PairingError
 from logitech_receiver.hidpp10_constants import Registers
 
 _hidpp10 = hidpp10.Hidpp10()
@@ -247,7 +248,7 @@ def test_set_3leds_missing(device, mocker):
 def test_get_notification_flags(device):
     result = _hidpp10.get_notification_flags(device)
 
-    assert result == int("000900", 16)
+    assert result == hidpp10_constants.NotificationFlag(int("000900", 16))
 
 
 def test_set_notification_flags(mocker):
@@ -278,17 +279,19 @@ def test_set_notification_flags_bad(mocker):
     "flag_bits, expected_names",
     [
         (None, ""),
-        (0x0, "none"),
-        (0x009020, "multi touch\n               unknown:008020"),
-        (0x080000, "mouse extra buttons"),
+        (hidpp10_constants.NotificationFlag(0x0), "none"),
+        (hidpp10_constants.NotificationFlag(0x001000), "multi touch"),
+        (hidpp10_constants.NotificationFlag(0x080000), "mouse extra buttons"),
         (
-            0x080000 + 0x000400,
+            hidpp10_constants.NotificationFlag(0x080400),
             ("link quality\n               mouse extra buttons"),
         ),
     ],
 )
 def test_notification_flag_str(flag_bits, expected_names):
-    flag_names = hidpp10_constants.flags_to_str(flag_bits, fallback="none")
+    flag_names = hidpp10_constants.flags_to_str(
+        hidpp10_constants.NotificationFlag(flag_bits) if flag_bits is not None else None, fallback="none"
+    )
 
     assert flag_names == expected_names
 
@@ -338,3 +341,11 @@ def test_set_configuration_pending_flags(device, expected_result):
     result = hidpp10.set_configuration_pending_flags(device, 0x00)
 
     assert result == expected_result
+
+
+def test_pairing_error():
+    expected_label = "device not supported"
+
+    res = PairingError.DEVICE_NOT_SUPPORTED.label
+
+    assert res == expected_label
